@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -51,7 +51,12 @@ switch (get_request_var('action')) {
 		$name  = get_nfilter_request_var('name');
 		$value = get_nfilter_request_var('value');
 
-		api_auth_update_user_setting($name, $value);
+		$current_tab = get_nfilter_request_var('tab');
+		if ($current_tab == 'general') {
+			api_auth_update_user_setting($name, $value);
+		} else {
+			api_plugin_hook_function('auth_profile_update_data', $current_tab);
+		}
 
 		break;
 	default:
@@ -454,6 +459,7 @@ function settings_javascript() {
 	function clearUserSettings() {
 		$.get('auth_profile.php?action=clear_user_settings', function() {
 			document.location = 'auth_profile.php?newtheme=1';
+			$('#clear_settings').blur();
 		});
 	}
 
@@ -463,6 +469,7 @@ function settings_javascript() {
 
 		$('body').append('<div style="display:none;" id="cleared" title="<?php print __esc('Private Data Cleared');?>"><p><?php print __('Your Private Data has been cleared.');?></p></div>');
 
+		$('#private_data').blur();
 		$('#cleared').dialog({
 			modal: true,
 			resizable: false,
@@ -480,6 +487,7 @@ function settings_javascript() {
 	}
 
 	function logoutEverywhere() {
+		$('#logout_everywhere').blur();
 		$.get('auth_profile.php?action=logout_everywhere', function(data) {
 			$('body').append('<div style="display:none;" id="cleared" title="<?php print __esc('User Sessions Cleared');?>"><p><?php print __('All your login sessions have been cleared.');?></p></div>');
 
@@ -632,6 +640,9 @@ function settings_javascript() {
 		$('#return').click(function() {
 			document.location = '<?php print $_SESSION['profile_referer'];?>';
 		});
+
+		// set the buttons active
+		$('#clear_settings, #private_data, #logout_everywhere').addClass('ui-state-active');
 	});
 
 	</script>
