@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,9 +23,22 @@
 */
 
 include('./include/auth.php');
-include_once('./lib/api_device.php');
+include_once('./lib/api_aggregate.php');
+include_once('./lib/api_automation.php');
 include_once('./lib/api_data_source.php');
+include_once('./lib/api_device.php');
+include_once('./lib/api_graph.php');
+include_once('./lib/api_tree.php');
+include_once('./lib/html_form_template.php');
+include_once('./lib/data_query.php');
+include_once('./lib/html_graph.php');
+include_once('./lib/html_tree.php');
+include_once('./lib/ping.php');
 include_once('./lib/poller.php');
+include_once('./lib/reports.php');
+include_once('./lib/rrd.php');
+include_once('./lib/snmp.php');
+include_once('./lib/template.php');
 include_once('./lib/utility.php');
 
 $device_actions = array(
@@ -181,21 +194,21 @@ function form_actions() {
 			</tr>
 			<tr>
 				<td class='textArea odd'>
-					<table><tr><td>" . __('Pollers') . "</td><td>\n";
+					<table><tr><td>" . __('Pollers') . "</td><td>";
 
 			form_dropdown('poller_id', $pollers, 'name', 'id', '', '', '');
 
-			print "</td></tr><tr><td>" . __('Select Template') . "</td><td>\n";
+			print "</td></tr><tr><td>" . __('Select Template') . "</td><td>";
 
 			form_dropdown('host_template', $available_host_templates, 'name', 'id', '', '', $host_template);
 
-			print "</td></tr>\n";
+			print "</td></tr>";
 
-			print "<tr><td>" . __('Availability Method') . "</td><td>\n";
+			print "<tr><td>" . __('Availability Method') . "</td><td>";
 
 			form_dropdown('availability_method', $availability_options, '', '', '', '', $availability_method);
 
-			print "</td></tr></table></td></tr>\n";
+			print "</td></tr></table></td></tr>";
 
 			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Add Device(s)') . "'>";
 		}
@@ -212,7 +225,7 @@ function form_actions() {
 			<input type='hidden' name='drp_action' value='" . get_request_var('drp_action') . "'>
 			$save_html
 		</td>
-	</tr>\n";
+	</tr>";
 
 	html_end_box();
 
@@ -275,14 +288,6 @@ function display_discovery_page() {
 		foreach($results as $host) {
 			form_alternate_row('line' . base64_encode($host['ip']), true);
 
-			if ($host['sysUptime'] != 0) {
-				$days = intval($host['sysUptime']/8640000);
-				$hours = intval(($host['sysUptime'] - ($days * 8640000)) / 360000);
-				$uptime = $days . 'd:' . $hours . 'h';
-			} else {
-				$uptime = '';
-			}
-
 			if ($host['hostname'] == '') {
 				$host['hostname'] = __('Not Detected');
 			}
@@ -294,7 +299,7 @@ function display_discovery_page() {
 			form_selectable_cell(snmp_data($host['sysContact']), $host['id'], '', 'text-align:left');
 			form_selectable_cell(snmp_data($host['sysDescr']), $host['id'], '', 'text-align:left;white-space:normal;');
 			form_selectable_cell(snmp_data($host['os']), $host['id'], '', 'text-align:left');
-			form_selectable_cell(snmp_data($uptime), $host['id'], '', 'text-align:right');
+			form_selectable_cell(snmp_data(get_uptime($host)), $host['id'], '', 'text-align:right');
 			form_selectable_cell($status[$host['snmp']], $host['id'], '', 'text-align:right');
 			form_selectable_cell($status[$host['up']], $host['id'], '', 'text-align:right');
 			form_selectable_cell(substr($host['mytime'],0,16), $host['id'], '', 'text-align:right');
@@ -333,10 +338,9 @@ function process_request_vars() {
 
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK,
+			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
-			'default' => '',
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
@@ -409,7 +413,7 @@ function get_discovery_results(&$total_rows = 0, $rows = 0, $export = false) {
 	}
 
 	if ($filter != '') {
-		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . "(hostname LIKE '%$filter%' OR ip LIKE '%$filter%')";
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . '(hostname LIKE ' . db_qstr('%' . $filter . '%') . ' OR ip LIKE ' . db_qstr('%' . $filter . '%') . ')';
 	}
 
 	if ($export) {
@@ -425,7 +429,7 @@ function get_discovery_results(&$total_rows = 0, $rows = 0, $export = false) {
 		$sql_order = get_order_string();
 		$sql_limit = ' LIMIT ' . ($rows*($page-1)) . ',' . $rows;
 
-		$sql_query = "SELECT *, FROM_UNIXTIME(time) AS mytime
+		$sql_query = "SELECT *,sysUptime snmp_sysUpTimeInstance, FROM_UNIXTIME(time) AS mytime
 			FROM automation_devices
 			$sql_where
 			$sql_order
@@ -460,9 +464,9 @@ function draw_filter() {
 							<option value='-1' <?php if (get_request_var('network') == -1) {?> selected<?php }?>><?php print __('Any');?></option>
 							<?php
 							if (cacti_sizeof($networks)) {
-							foreach ($networks as $key => $name) {
-								print "<option value='" . $key . "'"; if (get_request_var('network') == $key) { print ' selected'; } print '>' . $name . "</option>\n";
-							}
+								foreach ($networks as $key => $name) {
+									print "<option value='" . $key . "'"; if (get_request_var('network') == $key) { print ' selected'; } print '>' . $name . "</option>";
+								}
 							}
 							?>
 						</select>
@@ -490,9 +494,9 @@ function draw_filter() {
 							<option value='-1' <?php if (get_request_var('status') == '') {?> selected<?php }?>><?php print __('Any');?></option>
 							<?php
 							if (cacti_sizeof($status_arr)) {
-							foreach ($status_arr as $st) {
-								print "<option value='" . $st . "'"; if (get_request_var('status') == $st) { print ' selected'; } print '>' . $st . "</option>\n";
-							}
+								foreach ($status_arr as $st) {
+									print "<option value='" . $st . "'"; if (get_request_var('status') == $st) { print ' selected'; } print '>' . $st . "</option>";
+								}
 							}
 							?>
 						</select>
@@ -505,9 +509,9 @@ function draw_filter() {
 							<option value='-1' <?php if (get_request_var('os') == '') {?> selected<?php }?>><?php print __('Any');?></option>
 							<?php
 							if (cacti_sizeof($os_arr)) {
-							foreach ($os_arr as $st) {
-								print "<option value='" . $st . "'"; if (get_request_var('os') == $st) { print ' selected'; } print '>' . $st . "</option>\n";
-							}
+								foreach ($os_arr as $st) {
+									print "<option value='" . $st . "'"; if (get_request_var('os') == $st) { print ' selected'; } print '>' . $st . "</option>";
+								}
 							}
 							?>
 						</select>
@@ -520,9 +524,9 @@ function draw_filter() {
 							<option value='-1' <?php if (get_request_var('snmp') == '') {?> selected<?php }?>><?php print __('Any');?></option>
 							<?php
 							if (cacti_sizeof($status_arr)) {
-							foreach ($status_arr as $st) {
-								print "<option value='" . $st . "'"; if (get_request_var('snmp') == $st) { print ' selected'; } print '>' . $st . "</option>\n";
-							}
+								foreach ($status_arr as $st) {
+									print "<option value='" . $st . "'"; if (get_request_var('snmp') == $st) { print ' selected'; } print '>' . $st . "</option>";
+								}
 							}
 							?>
 						</select>
@@ -535,9 +539,9 @@ function draw_filter() {
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
 							if (cacti_sizeof($item_rows) > 0) {
-							foreach ($item_rows as $key => $value) {
-								print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
-							}
+								foreach ($item_rows as $key => $value) {
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>";
+								}
 							}
 							?>
 						</select>
