@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -204,6 +204,10 @@ if (cacti_sizeof($parms)) {
 			case 'pingsnmp':
 				$avail = AVAIL_SNMP_AND_PING;
 
+				break;
+			case 'pingorsnmp':
+				$avail = AVAIL_SNMP_OR_PING;
+
 				break;
 			default:
 				print "ERROR: Invalid Availability Parameter: ($value)\n\n";
@@ -320,16 +324,21 @@ if (cacti_sizeof($parms)) {
 		exit(1);
 	}
 
-	if ($description == "") {
+	if ($description == '') {
 		print "ERROR: You must supply a description for all hosts!\n";
 		exit(1);
 	}
 
-	if ($ip == "") {
+	if ($ip == '') {
 		print "ERROR: You must supply an IP address for all hosts!\n";
 		exit(1);
 	}
 
+	if ($snmp_ver > 3 || $snmp_ver < 0 || !is_numeric($snmp_ver)) {
+		print "ERROR: The snmp version must be between 0 and 3.  If you did not specify one, goto Configuration > Settings > Device Defaults and resave your defaults.\n";
+		exit(1);
+	}
+
 	/* process ip */
 	if (isset($addresses[$ip])) {
 		$id    = $addresses[$ip];
@@ -339,7 +348,7 @@ if (cacti_sizeof($parms)) {
 		if ($phost['snmp_version'] < '3' && $snmp_ver < '3') {
 			if ($snmp_ver == 0 && $proxy) {
 				// proxy but for no snmp
-			} elseif ($phost['snmp_community'] != $community) {
+			} elseif ($phost['snmp_community'] != $community || $phost['snmp_port'] != $snmp_port) {
 				if ($proxy) {
 					// assuming an snmp-proxy
 				} else {
@@ -478,7 +487,7 @@ function display_help() {
 	print "    --poller       0, numeric poller id that will perform data collection for the device.\n";
 	print "    --site         0, numeric site id that will be associated with the device.\n";
 	print "    --threads      1, numeric number of threads to poll device with.\n";
-	print "    --avail        pingsnmp, [ping][none, snmp, pingsnmp]\n";
+	print "    --avail        pingsnmp, [ping][none, snmp, pingsnmp, pingorsnmp]\n";
 	print "    --ping_method  tcp, icmp|tcp|udp\n";
 	print "    --ping_port    '', 1-65534\n";
 	print "    --ping_retries 2, the number of time to attempt to communicate with a host\n";
@@ -494,7 +503,7 @@ function display_help() {
 	print "    --privproto    '', snmp privacy protocol for snmpv3\n";
 	print "    --context      '', snmp context for snmpv3\n";
 	print "    --engineid     '', snmp engineid for snmpv3\n";
-	print "    --max_oids     10, 1-60, the number of OID's that can be obtained in a single SNMP Get request\n\n";
+	print "    --max_oids     10, 1-60, the number of OIDs that can be obtained in a single SNMP Get request\n\n";
 	print "List Options:\n";
 	print "    --list-host-templates\n";
 	print "    --list-communities\n";
