@@ -129,14 +129,8 @@ if (isset_request_var('rra_id')) {
 	$rra_id = null;
 }
 
-// Capture permission errors
-if (!is_graph_allowed(get_request_var('local_graph_id'))) {
-	header('Content-type: image/'. $gtype);
-	print rrdtool_create_error_image(__('Permission Denied.  Either this Graph does not exist or you do not have permission to access it.'));
-	exit;
-}
-
-$output = rrdtool_function_graph(get_request_var('local_graph_id'), $rra_id, $graph_data_array);
+$null_param = array();
+$output = rrdtool_function_graph(get_request_var('local_graph_id'), $rra_id, $graph_data_array, '', $null_param, $_SESSION['sess_user_id']);
 
 if ($output !== false && $output != '') {
 	/* flush the headers now */
@@ -149,7 +143,8 @@ if ($output !== false && $output != '') {
 
 	/* get the error string */
 	$graph_data_array['get_error'] = true;
-	rrdtool_function_graph(get_request_var('local_graph_id'), $rra_id, $graph_data_array);
+	$null_param = array();
+	rrdtool_function_graph(get_request_var('local_graph_id'), $rra_id, $graph_data_array, '', $null_param, $_SESSION['sess_user_id']);
 
 	$error = ob_get_contents();
 
