@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -143,7 +143,7 @@ $fields_snmp_item = array(
 $fields_snmp_item_with_oids = $fields_snmp_item + array(
 	'max_oids' => array(
 		'method' => 'textbox',
-		'friendly_name' => __("Maximum OID's Per Get Request"),
+		'friendly_name' => __("Maximum OIDs Per Get Request"),
 		'description' => __('Specified the number of OIDs that can be obtained in a single SNMP Get request.'),
 		'value' => '|arg1:max_oids|',
 		'max_length' => '8',
@@ -1353,20 +1353,27 @@ $fields_data_query_item_edit = array(
 		'value' => '|arg1:graph_template_id|',
 		'sql' => 'SELECT DISTINCT gt.id, gt.name
 			FROM graph_templates AS gt
-			INNER JOIN graph_templates_graph AS gtg
-			ON gt.id = gtg.graph_template_id
-			INNER JOIN graph_templates_item AS gti
-			ON gtg.graph_template_id=gti.graph_template_id
-			INNER JOIN data_template_rrd AS dtr
-			ON gti.task_item_id=dtr.id
-			INNER JOIN data_template_data AS dtd
-			ON dtd.data_template_id=dtr.data_template_id
-			AND dtd.local_data_id = 0
-			WHERE gtg.local_graph_id=0
-			AND dtr.local_data_id = 0
-			AND dtd.local_data_id = 0
-			AND dtd.data_input_id in (2,11,12)
-			ORDER BY gt.name'
+			WHERE gt.id IN(
+				SELECT DISTINCT gti.graph_template_id
+				FROM (
+					SELECT DISTINCT graph_template_id, task_item_id
+					FROM graph_templates_item
+					WHERE local_graph_id=0
+				) AS gti
+				INNER JOIN (
+					SELECT id, data_template_id
+					FROM data_template_rrd AS dtr
+					WHERE dtr.local_data_id = 0
+				) AS dtr
+				ON gti.task_item_id=dtr.id
+				INNER JOIN (
+					SELECT DISTINCT data_template_id
+					FROM data_template_data AS dtd
+					WHERE local_data_id = 0
+					AND dtd.data_input_id IN (2,11,12)
+				) AS dtd
+				ON dtd.data_template_id=dtr.data_template_id
+			) ORDER BY gt.name',
 		),
 	'name' => array(
 		'method' => 'textbox',
@@ -1737,6 +1744,13 @@ $struct_aggregate = array(
 		'value' => '|arg1:gprint_prefix|',
 		'size' => '40'
 	),
+	'gprint_format' => array(
+		'friendly_name' => __('Include Prefix Text'),
+		'description' => __('Include the source Graphs GPRINT Title Text with the Aggregate Graph(s).'),
+		'method' => 'checkbox',
+		'value' => '|arg1:gprint_format|',
+		'default' => ''
+	),
 	'aggregate_graph_type' => array(
 		'friendly_name' => __('Graph Type'),
 		'description' => __('Use this Option to create e.g. STACKed graphs.<br>AREA/STACK: 1st graph keeps AREA/STACK items, others convert to STACK<br>LINE1: all items convert to LINE1 items<br>LINE2: all items convert to LINE2 items<br>LINE3: all items convert to LINE3 items'),
@@ -1816,6 +1830,13 @@ $struct_aggregate_graph = array(
 		'value' => '|arg1:gprint_prefix|',
 		'size' => '40'
 	),
+	'gprint_format' => array(
+		'friendly_name' => __('Include Prefix Text'),
+		'description' => __('Include the source Graphs GPRINT Title Text with the Aggregate Graph(s).'),
+		'method' => 'checkbox',
+		'value' => '|arg1:gprint_format|',
+		'default' => ''
+	),
 	'graph_type' => array(
 		'friendly_name' => __('Graph Type'),
 		'description' => __('Use this Option to create e.g. STACKed graphs.<br>AREA/STACK: 1st graph keeps AREA/STACK items, others convert to STACK<br>LINE1: all items convert to LINE1 items<br>LINE2: all items convert to LINE2 items<br>LINE3: all items convert to LINE3 items'),
@@ -1914,6 +1935,13 @@ $struct_aggregate_template = array(
 		'value' => '|arg1:gprint_prefix|',
 		'size' => '40'
 	),
+	'gprint_format' => array(
+		'friendly_name' => __('Include Prefix Text'),
+		'description' => __('Include the source Graphs GPRINT Title Text with the Aggregate Graph(s).'),
+		'method' => 'checkbox',
+		'value' => '|arg1:gprint_format|',
+		'default' => ''
+	),
 	'graph_type' => array(
 		'friendly_name' => __('Graph Type'),
 		'description' => __('Use this Option to create e.g. STACKed graphs.<br>AREA/STACK: 1st graph keeps AREA/STACK items, others convert to STACK<br>LINE1: all items convert to LINE1 items<br>LINE2: all items convert to LINE2 items<br>LINE3: all items convert to LINE3 items'),
