@@ -13,32 +13,28 @@ var url;
 
 function realtimeDetectBrowser() {
 	if (navigator.userAgent.indexOf('MSIE') >= 0) {
-		browser = "IE";
+		var browser = 'IE';
 	}else if (navigator.userAgent.indexOf('Chrome') >= 0) {
-		browser = 'Chrome';
+		var browser = 'Chrome';
 	}else if (navigator.userAgent.indexOf('Mozilla') >= 0) {
-		browser = "FF";
+		var browser = 'FF';
 	}else if (navigator.userAgent.indexOf('Opera') >= 0) {
-		browser = "Opera";
+		var browser = 'Opera';
 	}else{
-		browser = "Other";
+		var browser = 'Other';
 	}
 
 	return browser;
 }
 
 function imageOptionsChanged(action) {
-	graph_start    = $("#graph_start").val();
-	graph_end      = 0;
-	ds_step        = $("#ds_step").val();
-	size           = $('#size').val();
-	isThumb        = $('#thumbnails').is(':checked');
-
-	if ($('#local_graph_id').length) {
-		local_graph_id = $('#local_graph_id').val();
-	} else {
-		local_graph_id = 0;
-	}
+	var graph_start    = $('#graph_start').val();
+	var graph_end      = 0;
+	var ds_step        = $('#ds_step').val();
+	var size           = $('#size').val();
+	var isThumb        = $('#thumbnails').is(':checked');
+	var url            = '';
+	var local_graph_id = $('#local_graph_id').val();
 
 	if (rtWidth == 0) {
 		rtWidth = $(window).width();
@@ -49,33 +45,47 @@ function imageOptionsChanged(action) {
 	}
 
 	if (action == 'countdown') {
-		url="graph_realtime.php?action=countdown&top=0&left=0&action="+action+"&local_graph_id="+local_graph_id;
+		url = 'graph_realtime.php?action=countdown&top=0&left=0&local_graph_id='+local_graph_id;
 	} else if (action == 'initial') {
-		url="graph_realtime.php?action=initial&top=0&left=0&action="+action+"&local_graph_id="+local_graph_id+"&graph_start=-"+(parseInt(graph_start) > 0 ? graph_start:'60')+"&ds_step="+ds_step+"&count="+count+"&size="+size;
+		url = 'graph_realtime.php?action=initial&top=0&left=0&local_graph_id='+local_graph_id+'&graph_start=-'+(parseInt(graph_start) > 0 ? graph_start:'60')+'&ds_step='+ds_step+'&count='+count+'&size='+size;
 	} else {
-		url="graph_realtime.php?action="+action+"&top=0&left=0&action="+action+"&local_graph_id="+local_graph_id+"&graph_start=-"+(parseInt(graph_start) > 0 ? graph_start:'60')+"&ds_step="+ds_step+"&count="+count+"&size="+size+"&graph_nolegend="+isThumb;
+		url = 'graph_realtime.php?action='+action+'&top=0&left=0&local_graph_id='+local_graph_id+'&graph_start=-'+(parseInt(graph_start) > 0 ? graph_start:'60')+'&ds_step='+ds_step+'&count='+count+'&size='+size+'&graph_nolegend='+isThumb;
 	}
 
 	Pace.stop;
 
 	$.getJSON(url)
 		.done(function(data) {
-			$('#image').empty().append('<img id="rimage" class="realtimeimage" src="data:image/png;base64,'+data.data+'"/>');
+			if ($('#rimage').length) {
+				$('#rimage').attr('src', 'data:image/png;base64,'+data.data);
+			} else {
+				$('#image').html('<img id="rimage" class="realtimeimage" src="data:image/png;base64,'+data.data+'"/>');
+			}
+
 			if (realtimePopout) {
 				setRealtimeWindowSize();
-				$('#ds_step').val(data.ds_step);
-				if ($('#ds_step').selectmenu('instance') !== undefined) {
-					$('#ds_step').selectmenu('refresh');
+
+				if ($('#ds_step').val() != data.ds_step) {
+					$('#ds_step').val(data.ds_step);
+					if ($('#ds_step').selectmenu('instance') !== undefined) {
+						$('#ds_step').selectmenu('refresh');
+					}
 				}
 
-				$('#graph_start').val(Math.abs(data.graph_start));
-				if ($('#graph_start').selectmenu('instance') !== undefined) {
-					$('#graph_start').selectmenu('refresh');
+				var curStart = Math.abs(data.graph_start);
+
+				if ($('#graph_start').val() != curStart) {
+					$('#graph_start').val(Math.abs(data.graph_start));
+					if ($('#graph_start').selectmenu('instance') !== undefined) {
+						$('#graph_start').selectmenu('refresh');
+					}
 				}
 
-				$('#size').val(data.size);
-				if ($('#size').selectmenu('instance') !== undefined) {
-					$('#size').selectmenu('refresh');
+				if ($('#size').val() != data.size) {
+					$('#size').val(data.size);
+					if ($('#size').selectmenu('instance') !== undefined) {
+						$('#size').selectmenu('refresh');
+					}
 				}
 
 				if (data.thumbnails == 'true') {
@@ -83,6 +93,8 @@ function imageOptionsChanged(action) {
 				} else {
 					$('#thumbnails').prop('checked', false);
 				}
+
+				destroy(data);
 			}
 		})
 		.fail(function(data) {
@@ -93,9 +105,9 @@ function imageOptionsChanged(action) {
 function setRealtimeWindowSize() {
 	if (realtimePopout == true) {
 		/* set the window size */
-		height1 = $('#rtfilter').outerHeight() + 60;
-		height2 = $('#rimage').outerHeight() + 30;
-		width   = $('#rimage').outerWidth() + 40;
+		var height1 = $('#rtfilter').outerHeight() + 60;
+		var height2 = $('#rimage').outerHeight() + 30;
+		var width   = $('#rimage').outerWidth() + 40;
 
 		if (width > 60) {
 			window.outerHeight = height1+height2;
@@ -106,8 +118,10 @@ function setRealtimeWindowSize() {
 }
 
 function stopRealtime() {
+	var graph;
+
 	for (key in realtimeArray) {
-		graph_id=key;
+		graph_id = key;
 
 		$('#wrapper_'+graph_id).html(keepRealtime[graph_id]).change();
 		$('#graph_'+graph_id+'_realtime').html("<img class='drillDown' alt='' title='"+realtimeClickOn+"' src='"+urlPath+"images/chart_curve_go.png'>").find('img').tooltip();
@@ -135,6 +149,8 @@ function stopRealtime() {
 
 function setFilters() {
 	var inRT = false;
+	var key;
+
 	for (key in realtimeArray) {
 		if (realtimeArray[key] == true) {
 			inRT = true;
@@ -170,17 +186,18 @@ function realtimeGrapher() {
 		originalRefresh = refreshMSeconds;
 	}
 
-	graph_start = $('#graph_start').val();
-	graph_end   = 0;
-	ds_step     = $('#ds_step').val();
-	size        = $('#size').val();
-	inRealtime  = false;
-    isThumb     = $('#thumbnails').is(':checked');
+	var graph_start = $('#graph_start').val();
+	var graph_end   = 0;
+	var ds_step     = $('#ds_step').val();
+	var size        = $('#size').val();
+	var inRealtime  = false;
+    var isThumb     = $('#thumbnails').is(':checked');
+	var key;
 
 	for (key in realtimeArray) {
 		if (realtimeArray[key] == true) {
 			inRealtime = true;
-			local_graph_id=key
+			local_graph_id = key
 
 			if (isThumb) {
 				if (rtWidth == 0) {
@@ -189,7 +206,7 @@ function realtimeGrapher() {
 				}
 			}
 
-			position = $('#wrapper_'+local_graph_id).find('img').position();
+			var position = $('#wrapper_'+local_graph_id).find('img').position();
 
 			Pace.ignore(function() {
 				position = $('#wrapper_'+local_graph_id).find('img').position();
@@ -198,13 +215,17 @@ function realtimeGrapher() {
 					.done(function(data) {
 						results = $.parseJSON(data);
 
-						$('#graph_'+results.local_graph_id).prop('src', 'data:image/png;base64,'+results.data).change();
+						$('#graph_'+results.local_graph_id).attr('src', 'data:image/png;base64,'+results.data).change();
 
 						if (isThumb) {
 							$('#graph_'+results.local_graph_id).width(rtWidth).height(rtHeight);
 						}else{
 							$('#graph_'+results.local_graph_id);
 						}
+
+						destroy(data);
+						destroy(results);
+						destroy(position);
 					})
 					.fail(function(data) {
 						getPresentHTTPError(data);
@@ -218,7 +239,19 @@ function realtimeGrapher() {
 		stopRealtime();
 	} else {
 		count--;
+		destroy(realtimeTimer);
 		realtimeTimer = setTimeout('realtimeGrapher()', $('#ds_step').val()*1000);
 	}
 }
 
+function destroy(obj) {
+	for (var prop in obj){
+		var property = obj[prop];
+
+		if (property != null && typeof(property) == 'object') {
+            destroy(property);
+        } else {
+            obj[prop] = null;
+        }
+	}
+}
