@@ -7,8 +7,6 @@ function themeReady() {
 	var hostOpen = false;
 
 	$('body').css('height', $(window).height());
-	$('#navigation').css('height', ($(window).height()-80)+'px');
-	$('#navigation_right').css('height', ($(window).height()-80)+'px');
 	$('.formItemDescription').hide();
 
 	keepWindowSize();
@@ -218,7 +216,6 @@ function setMenuVisibility() {
 		}
 
 		if ($(this).find('a.selected').length == 0) {
-			console.log('hiding1:'+$(this).closest('.menuitem').attr('id'));
 			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
 			$(this).next('a').hide();
 			storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
