@@ -23,6 +23,9 @@
  +-------------------------------------------------------------------------+
 */
 
+global $original_memory_limit;
+
+$original_memory_limit = ini_get('memory_limit');
 ini_set('memory_limit','-1');
 
 include(dirname(__FILE__) . '/../include/cli_check.php');
