@@ -384,7 +384,7 @@ function api_data_source_disable_multi($local_data_ids) {
 			if (!($i % 1000)) {
 				$poller_ids = array_rekey(db_fetch_assoc('SELECT poller_id
 					FROM poller_item
-					WHERE local_data_id IN(' . $ids_to_delete . ')'), 'poller_id', 'poller_id');
+					WHERE local_data_id IN(' . $ids_to_disable . ')'), 'poller_id', 'poller_id');
 
 				db_execute("DELETE FROM poller_item WHERE local_data_id IN ($ids_to_disable)");
 				db_execute("UPDATE data_template_data SET active='' WHERE local_data_id IN ($ids_to_disable)");
@@ -407,7 +407,7 @@ function api_data_source_disable_multi($local_data_ids) {
 			$poller_ids = array_rekey(
 				db_fetch_assoc('SELECT poller_id
 					FROM poller_item
-					WHERE local_data_id IN(' . $ids_to_delete .')'),
+					WHERE local_data_id IN(' . $ids_to_disable .')'),
 				'poller_id', 'poller_id'
 			);
 
@@ -552,8 +552,12 @@ function api_reapply_suggested_data_source_data($local_data_id) {
 		ORDER BY sequence",
 		array($snmp_query_graph_id, $data_local['data_template_id']));
 
+	$matches = array();
+
 	if (cacti_sizeof($svs)) {
 		foreach ($svs as $sv) {
+			$sv['text'] = trim($sv['text']);
+
 			if (($sv['text'] == '|query_ifSpeed|' || $sv['text'] == '|query_ifHighSpeed|') && $sv['field_name'] == 'rrd_maximum') {
 				$subs_string = api_data_source_get_interface_speed($data_local);
 				$sv['text']  = $subs_string;
@@ -564,13 +568,19 @@ function api_reapply_suggested_data_source_data($local_data_id) {
 			}
 
 			/* if there are no '|query' characters, all of the substitutions were successful */
-			if (!substr_count($subs_string, '|query')) {
+			if (strpos($subs_string, '|query') === false) {
+				if (in_array($sv['field_name'], $matches)) {
+					continue;
+				}
+
 				if (db_column_exists('data_template_data', $sv['field_name'])) {
+					$matches[] = $sv['field_name'];
 					db_execute_prepared('UPDATE data_template_data
 						SET ' . $sv['field_name'] . ' = ?
 						WHERE local_data_id = ?',
 						array($sv['text'], $local_data_id));
 				} elseif (db_column_exists('data_template_rrd', $sv['field_name'])) {
+					$matches[] = $sv['field_name'];
 					db_execute_prepared('UPDATE data_template_rrd
 						SET ' . $sv['field_name'] . ' = ?
 						WHERE local_data_id = ?',
@@ -578,9 +588,6 @@ function api_reapply_suggested_data_source_data($local_data_id) {
 				} else {
 					cacti_log('ERROR: Suggested value column error.  Column ' . $sv['field_name'] . ' for Data Template ID ' . $data_local['data_template_id'] . ' is not a compatible field name for tables data_template_data and data_template_rrd.  Please correct this suggested value mapping', false);
 				}
-
-				/* once we find a working value for that very field, stop */
-				break;
 			}
 		}
 	}
