@@ -71,7 +71,11 @@ function set_auth_cookie($user) {
 			(?, ?, NOW(), ?);',
 			array($user['id'], get_client_addr(''), $secret));
 
-		setcookie('cacti_remembers', $user['username'] . ',' . $nssecret, time()+(86400*30), $config['url_path']);
+		if (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') {
+			setcookie('cacti_remembers', $user['username'] . ',' . $nssecret, time()+(86400*30), $config['url_path'], NULL, true, true);
+		} else {
+			setcookie('cacti_remembers', $user['username'] . ',' . $nssecret, time()+(86400*30), $config['url_path']);
+		}
 	}
 }
 
@@ -2269,7 +2273,7 @@ function get_host_array() {
 	$hosts = get_allowed_devices('', 'description', '', $total_rows);
 
 	foreach($hosts as $host) {
-		$return_devices[] = $host['description'] . ' (' . $host['hostname'] . ')';
+		$return_devices[] = strip_domain($host['description']) . ' (' . strip_domain($host['hostname']) . ')';
 	}
 
 	return $return_devices;
@@ -2297,7 +2301,7 @@ function get_allowed_ajax_hosts($include_any = true, $include_none = true, $sql_
 	$hosts = get_allowed_devices($sql_where, 'description', read_config_option('autocomplete_rows'), $total_rows);
 	if (cacti_sizeof($hosts)) {
 		foreach($hosts as $host) {
-			$return[] = array('label' => $host['description'], 'value' => $host['description'], 'id' => $host['id']);
+			$return[] = array('label' => strip_domain($host['description']), 'value' => $host['description'], 'id' => $host['id']);
 		}
 	}
 
