@@ -23,7 +23,7 @@
 */
 
 function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphans = false) {
-	global $config, $hash_type_codes, $cacti_version_codes, $preview_only, $remove_orphans, $import_debug_info;
+	global $config, $hash_type_codes, $cacti_version_codes, $preview_only, $remove_orphans, $import_debug_info, $legacy_template;
 
 	include_once($config['library_path'] . '/xml.php');
 
@@ -42,7 +42,9 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 		$parsed_hash = parse_xml_hash($hash);
 
 		/* invalid/wrong hash */
-		if ($parsed_hash == false) { return $info_array; }
+		if ($parsed_hash == false) {
+			return $info_array;
+		}
 
 		if (isset($dep_hash_cache[$parsed_hash['type']])) {
 			array_push($dep_hash_cache[$parsed_hash['type']], $parsed_hash);
@@ -159,6 +161,10 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 			for ($i=0; $i<cacti_count($dep_hash_cache[$type]); $i++) {
 				$import_debug_info = false;
 
+				if (!isset($cacti_version_codes[$dep_hash_cache[$type][$i]['version']])) {
+					return false;
+				}
+
 				cacti_log('$dep_hash_cache[$type][$i][\'type\']: ' . $dep_hash_cache[$type][$i]['type'], false, 'IMPORT', POLLER_VERBOSITY_HIGH);
 				cacti_log('$dep_hash_cache[$type][$i][\'version\']: ' . $dep_hash_cache[$type][$i]['version'], false, 'IMPORT', POLLER_VERBOSITY_HIGH);
 				cacti_log('$cacti_version_codes[$dep_hash_cache[$type][$i][\'version\']]: ' . $cacti_version_codes[$dep_hash_cache[$type][$i]['version']], false, 'IMPORT', POLLER_VERBOSITY_HIGH);
@@ -256,7 +262,7 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 	/* set new timeout and memory settings */
 	if ($limitex) {
 		ini_set('max_execution_time', '50');
-		ini_set('memory_limit', '384M');
+		ini_set('memory_limit', '-1');
 	}
 
 	$public_key = get_public_key();
@@ -275,7 +281,7 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 				$binary_signature =  base64_decode(trim(str_replace(array('<signature>', '</signature>'), array('', ''), $x)));
 				$x = "   <signature></signature>\n";
 
-				cacti_log('NOTE: Got Package Signature', false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+				cacti_log('NOTE: Got Package Signature', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 			}
 			$xml .= "$x";
 		}
@@ -297,7 +303,7 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 		return false;
 	}
 
-	cacti_log('Loading Plugin Information from package', false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+	cacti_log('Loading Plugin Information from package', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 	$xmlget     = simplexml_load_string($xml);
 	$data       = xml_to_array($xmlget);
@@ -310,7 +316,7 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 		exit;
 	}
 
-	cacti_log('Verifying each files signature', false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+	cacti_log('Verifying each files signature', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 	if (isset($data['files']['file']['data'])) {
 		$data['files']['file'] = array($data['files']['file']);
@@ -321,14 +327,14 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 		$fdata = base64_decode($f['data']);
 		$ok = openssl_verify($fdata, $binary_signature, $public_key, OPENSSL_ALGO_SHA1);
 		if ($ok == 1) {
-			cacti_log('NOTE: File OK: ' . $f['name'], false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+			cacti_log('NOTE: File OK: ' . $f['name'], false, 'IMPORT', POLLER_VERBOSITY_LOW);
 		} else {
 			cacti_log('FATAL: Could not Verify Signature for file: ' . $f['name'], true, 'IMPORT', POLLER_VERBOSITY_LOW);
 			return false;
 		}
 	}
 
-	cacti_log('Writing Files', false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+	cacti_log('Writing Files', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 	foreach ($data['files']['file'] as $f) {
 		$fdata = base64_decode($f['data']);
@@ -336,13 +342,14 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 
 		if (strpos($name, 'scripts/') !== false || strpos($name, 'resource/') !== false) {
 			$filename = $config['base_path'] . "/$name";
-			cacti_log('Writing file: ' . $filename, false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+			cacti_log('Writing file: ' . $filename, false, 'IMPORT', POLLER_VERBOSITY_LOW);
+
 			if (!$preview) {
-				if (is_writable($filename)) {
-					$file = fopen($filename,'wb');
+				if ((is_writeable(dirname($filename)) && !file_exists($filename)) || is_writable($filename)) {
+					$file = fopen($filename, 'wb');
 
 					if (is_resource($file)) {
-						fwrite($file ,$fdata, strlen($fdata));
+						fwrite($file , $fdata, strlen($fdata));
 						fclose($file);
 						clearstatcache();
 						$filestatus[$filename] = __('written');
@@ -358,6 +365,8 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 				} else {
 					$filestatus[$filename] = __('not writable');
 				}
+
+				cacti_log('Write Status file: ' . $filename . ', with Status ' . $filestatus[$filename], false, 'IMPORT', POLLER_VERBOSITY_LOW);
 			} else {
 				if (!is_writable($filename)) {
 					$filestatus[$filename] = __('not writable');
@@ -365,14 +374,19 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 					$filestatus[$filename] = __('writable');
 				}
 			}
+
 		} else {
 			cacti_log('Importing XML Data for ' . $name, false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 			$debug_data = import_xml_data($fdata, false, $profile_id, $remove_orphans, $preview_only);
+
+			if ($debug_data === false) {
+				return false;
+			}
 		}
 	}
 
-	cacti_log('File creation complete', false, 'IMPORT', POLLER_VERBOSITY_HIGH);
+	cacti_log('File creation complete', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 	return array($debug_data, $filestatus);
 }
@@ -392,9 +406,11 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 	if (!empty($_graph_template_id)) {
 		$previous_data = db_fetch_row_prepared('SELECT *
 			FROM graph_templates
-			WHERE id = ?', array($_graph_template_id));
+			WHERE id = ?',
+			array($_graph_template_id));
 	} else {
 		$previous_data = array();
+		clear_cached_allowed_types();
 	}
 
 	$save['id']   = (empty($_graph_template_id) ? '0' : $_graph_template_id);
@@ -421,8 +437,10 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 	$save['id'] = (empty($_graph_template_id) ? '0' : db_fetch_cell_prepared('SELECT gtg.id
 		FROM graph_templates AS gt
 		INNER JOIN graph_templates_graph AS gtg
-		ON gt.id=gtg.graph_template_id
-		WHERE gt.id = ? AND gtg.local_graph_id=0', array($graph_template_id)));
+		ON gt.id = gtg.graph_template_id
+		WHERE gt.id = ?
+		AND gtg.local_graph_id = 0',
+		array($graph_template_id)));
 
 	if (!empty($_graph_template_id)) {
 		$previous_data = db_fetch_row_prepared('SELECT *
@@ -499,7 +517,7 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 				FROM graph_templates_item
 				WHERE hash = ?
 				AND graph_template_id = ?
-				AND local_graph_id=0',
+				AND local_graph_id = 0',
 				array($parsed_hash['hash'], $graph_template_id));
 
 			if (!empty($_graph_template_item_id)) {
@@ -618,7 +636,7 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 
 						if (isset($hash_cache['graph_template_item'][$parsed_hash['hash']])) {
 							db_execute_prepared('REPLACE INTO graph_template_input_defs
-								(graph_template_input_id,graph_template_item_id)
+								(graph_template_input_id, graph_template_item_id)
 								VALUES (?, ?)',
 								array($graph_template_input_id, $hash_cache['graph_template_item'][$parsed_hash['hash']]));
 						}
@@ -669,7 +687,7 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 }
 
 function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new, $profile_id) {
-	global $struct_data_source, $struct_data_source_item, $import_template_id, $preview_only, $import_debug_info;
+	global $struct_data_source, $struct_data_source_item, $import_template_id, $preview_only, $import_debug_info, $legacy_template;
 
 	/* track changes */
 	$status = 0;
@@ -713,7 +731,8 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 		INNER JOIN data_template_data AS dtd
 		ON dt.id=dtd.data_template_id
 		WHERE dt.id = ?
-		AND dtd.local_data_id=0', array($data_template_id)));
+		AND dtd.local_data_id = 0',
+		array($data_template_id)));
 
 	if (!empty($save['id'])) {
 		$previous_data = db_fetch_row_prepared('SELECT *
@@ -787,7 +806,7 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 				FROM data_template_rrd
 				WHERE hash = ?
 				AND data_template_id = ?
-				AND local_data_id=0',
+				AND local_data_id = 0',
 				array($parsed_hash['hash'], $data_template_id));
 
 			if (!empty($_data_template_rrd_id)) {
@@ -833,12 +852,42 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 				$save['rrd_heartbeat'] = read_config_option('poller_interval') * 2;
 			}
 
+			if ($legacy_template) {
+				if ($save['data_source_type_id'] == 1 || $save['data_source_type_id'] == 4) {
+					if ($save['rrd_maximum'] == '0' && $save['rrd_minimum'] == '0') {
+						$save['rrd_maximum'] = 'U';
+					}
+				} elseif ($save['data_source_type_id'] == 3 || $save['data_source_type_id'] == 7) {
+					if ($save['rrd_maximum'] == '0' && $save['rrd_minimum'] == '0') {
+						$save['rrd_maximum'] = 'U';
+						$save['rrd_minimum'] = 'U';
+					}
+				}
+			}
+
 			/* check for status changes */
 			$status += compare_data($save, $previous_data, 'data_template_rrd');
 
 			if (!$preview_only) {
 				$data_template_rrd_id = sql_save($save, 'data_template_rrd');
 
+				if ($legacy_template) {
+					// Correct max values in templates and data sources: GAUGE/ABSOLUTE (1,4)
+					db_execute("UPDATE data_template_rrd
+						SET rrd_maximum='U'
+						WHERE rrd_maximum = '0'
+						AND rrd_minimum = '0'
+						AND data_template_id = $data_template_id
+						AND data_source_type_id IN(1,4)");
+
+					// Correct min/max values in templates and data sources: DERIVE/DDERIVE (3,7)
+					db_execute("UPDATE data_template_rrd
+						SET rrd_maximum='U', rrd_minimum='U'
+						WHERE (rrd_maximum = '0' OR rrd_minimum = '0')
+						AND data_template_id = $data_template_id
+						AND data_source_type_id IN(3,7)");
+				}
+
 				$hash_cache['data_template_item'][$parsed_hash['hash']] = $data_template_rrd_id;
 			} else {
 				$hash_cache['data_template_item'][$parsed_hash['hash']] = $_data_template_rrd_id;
@@ -1198,7 +1247,7 @@ function xml_to_data_source_profile($hash, &$xml_array, &$hash_cache, $import_as
 			if (!empty($hash_items[0])) {
 				for ($i=0; $i<cacti_count($hash_items); $i++) {
 					db_execute_prepared('REPLACE INTO data_source_profiles_cf
-						(data_source_profile_id,consolidation_function_id)
+						(data_source_profile_id, consolidation_function_id)
 						VALUES (?, ?)',
 						array($dsp_id, $hash_items[$i]));
 				}
@@ -1290,7 +1339,7 @@ function xml_to_host_template($hash, &$xml_array, &$hash_cache) {
 
 				if (isset($hash_cache['graph_template'][$parsed_hash['hash']])) {
 					db_execute_prepared('REPLACE INTO host_template_graph
-						(host_template_id,graph_template_id)
+						(host_template_id, graph_template_id)
 						VALUES (?, ?)',
 						array($host_template_id, $hash_cache['graph_template'][$parsed_hash['hash']]));
 				}
@@ -1310,7 +1359,7 @@ function xml_to_host_template($hash, &$xml_array, &$hash_cache) {
 
 				if (isset($hash_cache['data_query'][$parsed_hash['hash']])) {
 					db_execute_prepared('REPLACE INTO host_template_snmp_query
-						(host_template_id,snmp_query_id)
+						(host_template_id, snmp_query_id)
 						VALUES (?, ?)',
 						array($host_template_id, $hash_cache['data_query'][$parsed_hash['hash']]));
 				}
@@ -1877,6 +1926,8 @@ function resolve_hash_to_id($hash, &$hash_cache_array) {
 }
 
 function parse_xml_hash($hash) {
+	global $legacy_template;
+
 	if (preg_match('/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/', $hash, $matches)) {
 		$parsed_hash['type']    = check_hash_type($matches[1]);
 		$parsed_hash['version'] = strval(check_hash_version($matches[2]));
@@ -1916,6 +1967,10 @@ function parse_xml_hash($hash) {
 		return false;
 	}
 
+	if (cacti_version_compare($parsed_hash['version'], '1.2.3', '<')) {
+		$legacy_template = true;
+	}
+
 	return $parsed_hash;
 }
 
