@@ -212,87 +212,90 @@ function substitute_script_query_path($path) {
    @returns - the original string with all of the variable substitutions made */
 function substitute_host_data($string, $l_escape_string, $r_escape_string, $host_id) {
 	if (!empty($host_id)) {
-		if (!isset($_SESSION['sess_host_cache_array'][$host_id])) {
-			$host = db_fetch_row_prepared('SELECT ' . SQL_NO_CACHE . ' * FROM host WHERE id = ?', array($host_id));
-			if (!cacti_sizeof($host)) {
-				return $string;
-			}
+		$host = db_fetch_row_prepared('SELECT ' . SQL_NO_CACHE . ' h.*, s.name AS site_name
+			FROM host AS h
+			LEFT JOIN sites AS s
+			ON h.site_id = s.id
+			WHERE h.id = ?', array($host_id));
 
-			$_SESSION['sess_host_cache_array'][$host_id] = $host;
+		if (!cacti_sizeof($host)) {
+			return $string;
 		}
 
-
 		$search  = array();
 		$replace = array();
 
 		$search[]  = $l_escape_string . 'host_management_ip' . $r_escape_string; /* for compatibility */
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['hostname']; /* for compatibility */
+		$replace[] = $host['hostname']; /* for compatibility */
 
+		/* common host columns */
+		$search[]  = $l_escape_string . 'host_id' . $r_escape_string;
+		$replace[] = $host['id'];
 		$search[]  = $l_escape_string . 'host_hostname' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['hostname'];
+		$replace[] = $host['hostname'];
 		$search[]  = $l_escape_string . 'host_description' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['description'];
+		$replace[] = $host['description'];
+		$search[]  = $l_escape_string . 'host_site' . $r_escape_string;
+		$replace[] = $host['site_name'];
 		$search[]  = $l_escape_string . 'host_notes' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['notes'];
+		$replace[] = $host['notes'];
 		$search[]  = $l_escape_string . 'host_location' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['location'];
+		$replace[] = $host['location'];
 		$search[]  = $l_escape_string . 'host_polling_time' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['polling_time'];
+		$replace[] = $host['polling_time'];
 		$search[]  = $l_escape_string . 'host_avg_time' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['avg_time'];
+		$replace[] = $host['avg_time'];
 		$search[]  = $l_escape_string . 'host_cur_time' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['cur_time'];
+		$replace[] = $host['cur_time'];
 		$search[]  = $l_escape_string . 'host_availability' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['availability'];
+		$replace[] = $host['availability'];
 
 		/* snmp connectivity information */
 		$search[]  = $l_escape_string . 'host_snmp_community' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_community'];
+		$replace[] = $host['snmp_community'];
 		$search[]  = $l_escape_string . 'host_snmp_version' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_version'];
+		$replace[] = $host['snmp_version'];
 		$search[]  = $l_escape_string . 'host_snmp_username' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_username'];
+		$replace[] = $host['snmp_username'];
 		$search[]  = $l_escape_string . 'host_snmp_password' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_password'];
+		$replace[] = $host['snmp_password'];
 		$search[]  = $l_escape_string . 'host_snmp_auth_protocol' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_auth_protocol'];
+		$replace[] = $host['snmp_auth_protocol'];
 		$search[]  = $l_escape_string . 'host_snmp_priv_passphrase' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_priv_passphrase'];
+		$replace[] = $host['snmp_priv_passphrase'];
 		$search[]  = $l_escape_string . 'host_snmp_priv_protocol' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_priv_protocol'];
+		$replace[] = $host['snmp_priv_protocol'];
 		$search[]  = $l_escape_string . 'host_snmp_context' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_context'];
+		$replace[] = $host['snmp_context'];
 		$search[]  = $l_escape_string . 'host_snmp_engine_id' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_engine_id'];
+		$replace[] = $host['snmp_engine_id'];
 		$search[]  = $l_escape_string . 'host_snmp_port' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_port'];
+		$replace[] = $host['snmp_port'];
 		$search[]  = $l_escape_string . 'host_snmp_timeout' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_timeout'];
+		$replace[] = $host['snmp_timeout'];
 
 		/* snmp system information */
 		$search[]  = $l_escape_string . 'host_snmp_sysDescr' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysDescr'];
+		$replace[] = $host['snmp_sysDescr'];
 		$search[]  = $l_escape_string . 'host_snmp_sysObjectID' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysObjectID'];
+		$replace[] = $host['snmp_sysObjectID'];
 		$search[]  = $l_escape_string . 'host_snmp_sysContact' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysContact'];
+		$replace[] = $host['snmp_sysContact'];
 		$search[]  = $l_escape_string . 'host_snmp_sysLocation' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysLocation'];
+		$replace[] = $host['snmp_sysLocation'];
 		$search[]  = $l_escape_string . 'host_snmp_sysName' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysName'];
+		$replace[] = $host['snmp_sysName'];
 		$search[]  = $l_escape_string . 'host_snmp_sysUpTimeInstance' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['snmp_sysUpTimeInstance'];
+		$replace[] = $host['snmp_sysUpTimeInstance'];
 
 		$search[]  = $l_escape_string . 'host_ping_retries' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['ping_retries'];
+		$replace[] = $host['ping_retries'];
 		$search[]  = $l_escape_string . 'host_max_oids' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['max_oids'];
-		$search[]  = $l_escape_string . 'host_id' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['id'];
+		$replace[] = $host['max_oids'];
 
 		/* handle the external id */
 		$search[]  = $l_escape_string . 'host_external_id' . $r_escape_string;
-		$replace[] = $_SESSION['sess_host_cache_array'][$host_id]['external_id'];
+		$replace[] = $host['external_id'];
 
 		$string = str_replace($search, $replace, $string);
 
