@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -178,7 +178,7 @@ if ($run) {
 		SET status="5"
 		WHERE id= ?', array($poller_id), true, $remote_db_cnn_id);
 
-	poller_push_reindex_data_to_main();
+	poller_push_reindex_data_to_main(0, 0, true);
 
 	while (true) {
 		$time_records  = db_fetch_assoc('SELECT time, count(*) AS entries
